<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2010 form4 GmbH & Co. KG <t3x@form4.de>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

require_once(PATH_tslib.'class.tslib_pibase.php');

/**
 * Plugin 'Social Media Links' for the 'form4_socialmedialinks' extension.
 *
 * $Id: class.tx_form4socialmedialinks_pi1.php 2271 2010-04-29 15:38:04Z michael.huebe $
 * 
 * @author	form4 GmbH & Co. KG <t3x@form4.de>
 * @package	TYPO3
 * @subpackage	tx_form4socialmedialinks
 */
class tx_form4socialmedialinks_pi1 extends tslib_pibase {
	var $prefixId      = 'tx_form4socialmedialinks_pi1';		// Same as class name
	var $scriptRelPath = 'pi1/class.tx_form4socialmedialinks_pi1.php';	// Path to this script relative to the extension dir.
	var $extKey        = 'form4_socialmedialinks';	// The extension key.
	var $pi_checkCHash = true;
	
	/**
	 * Renders social media links
	 *
	 * @param	string		$content: The content of the PlugIn
	 * @param	array		$conf: The PlugIn Configuration
	 * @return	The content that should be displayed on the website
	 */
	function main($content, $conf)	{
		$this->conf = $conf;
		$this->pi_loadLL();
		$this->pi_initPIflexForm();
			
		$this->sys_language_uid = $GLOBALS['TSFE']->config['config']['sys_language_uid'];
		
		$medialinks = array();
		// try to get link items from flexform
		if(!is_null($this->pi_getFFvalue($this->cObj->data['pi_flexform'],'field_socialmedialinks'))) {
			$medialinks = explode(',', trim($this->pi_getFFvalue($this->cObj->data['pi_flexform'],'field_socialmedialinks')));
		}
		
		if(empty($medialinks)) {
			// no links in a flexform defined, so try ts configuration
			$tsConf = $this->cObj->stdWrap($this->conf['displayItems'], $this->conf['displayItems.']);
			$identifier = explode(',', $tsConf);
			if(!empty($identifier)) {
				foreach($identifier as $id) {
					$link = $this->getSocialMediaLinkByIdentifier($id);
					if($link) {
						$medialinks[] = $link['uid'];
					}
				}
			}
		}
		

		$extConf = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf'][$this->extKey]);
		$includeDefaultCss = is_array($extConf) ? $extConf['form4_socialmedialinks.']['includeDefaultCss'] : FALSE;
		
		if($includeDefaultCss) {
			// use TS definition to create correct css file path
			$ts  = '10 = TEXT'."\n";
			$ts .= '10.data = PATH:EXT:form4_socialmedialinks/res/css/default.css'."\n";
			// parse the helper TS
			$parseObj = t3lib_div::makeInstance('t3lib_TSparser');
			$parseObj->parse($ts);
			// resolve filename by a stdWrap
			$cssFile= $this->cObj->stdWrap($parseObj->setup['10'],$parseObj->setup['10.']);
			$GLOBALS['TSFE']->additionalHeaderData['tx_form4socialmedialinks_pi1'] .= '<link rel="stylesheet" type="text/css" media="all" href="'.$cssFile.'" />';
		}
		
		if(!empty($medialinks)) {
			
			// Get the template
			$this->templateCode = $this->cObj->fileResource($this->conf['templateFile']);
			// Get the parts out of the template
			$template['total'] 			= $this->cObj->getSubpart($this->templateCode,'###TEMPLATE###');
			$template['item_url']    	= $this->cObj->getSubpart($template['total'],'###ITEM_URL###');
			$template['item_url_icon']  = $this->cObj->getSubpart($template['item_url'],'###ITEM_ICON###');
			$template['item_script'] 	= $this->cObj->getSubpart($template['total'],'###ITEM_SCRIPT###');
			
			$placeholder = $this->preparePlaceholder();
			
			foreach($medialinks as $uid) {
				$socialmedialink = $this->getSocialMediaLink($uid);
				if($socialmedialink) {
					
					$url  = htmlspecialchars($socialmedialink['url']);
					$html = $socialmedialink['html'];
					
					foreach($placeholder as $key => $value) {
						$url  = str_replace('###'.$key.'###', $value, $url);
						$html = str_replace('###'.$key.'###', $value, $html);
					}
					
					// $this->getItemTSConfigValue($socialmedialink['identifier'], 'target')
					$iconData = $this->getItemIcon($socialmedialink);
					
					// fill up array, regarding to the type of the social media link
					if(intval($socialmedialink['type']) === 1) {
						$markerArray['###TITLE###']  = '';
						$markerArray['###URL###']    = '';
						$markerArray['###TARGET###'] = '';
						$markerArray['###ICON###']   = '';
						$markerArray['###SCRIPT###'] = $html;
						
						// Add subpart into a string
 						$socialmedia_items .= $this->cObj->substituteMarkerArrayCached($template['item_script'], $markerArray);
						
					} else {
						$markerArray['###TITLE###']  = htmlspecialchars($socialmedialink['title']);
						$markerArray['###URL###']    = $url;
						$markerArray['###TARGET###'] = $this->getItemTSConfigValue($socialmedialink['identifier'], 'target');
						$markerArray['###SCRIPT###'] = '';
						if($iconData) {
							$icon_markerArray['###ICON_URL###']    = $iconData['url'];
							$icon_markerArray['###ICON_WIDTH###']  = $iconData['width'];
							$icon_markerArray['###ICON_HEIGHT###'] = $iconData['height'];
							$icon_markerArray['###ICON_ALT###']    = $socialmedialink['title'];
							
							// replace markers in items icon part
							$socialmedia_item_icon = $this->cObj->substituteMarkerArrayCached($template['item_url_icon'], $icon_markerArray);
							// set content for items icon part
							$icon_subpartArray['###ITEM_ICON###'] = $socialmedia_item_icon; 
							
						} else {
							$icon_subpartArray['###ITEM_ICON###'] = '';
						}
						
						
						// Add subpart into a string
 						$socialmedia_items .= $this->cObj->substituteMarkerArrayCached($template['item_url'], $markerArray, $icon_subpartArray);
					}
				}
			}
			
			// Fill subpart marker
			$subpartArray['###CONTENT###'] = $socialmedia_items; 
			
			// Finalize and create the content by replacing the "content" marker in the template  
			$content = $this->cObj->substituteMarkerArrayCached($template['total'], array(), $subpartArray);
		}
		return $content;		
	}
	
	/**
	 *  Gets the typoscript configuration for a social media link item.
	 *  It tries to itentify the configuration of the special item first. If no special configuration
	 *  exist it returns the global value.
	 *
	 *  @param $identifier String Social media links global unique identifier
	 *  @param $key String Typoscript configuration key.
	 *  
	 *  @return String Value.
	 */
	function getItemTSConfigValue($identifier, $key) {
		$itemConf = $this->conf['item.'];
		
		// global default value
		$value = $this->cObj->stdWrap($itemConf[$key], $itemConf[$key].'.');
		if(!empty($itemConf[$identifier.'.']) && isset($itemConf[$identifier.'.'][$key])) {
			$value = $this->cObj->stdWrap($itemConf[$identifier.'.'][$key], $itemConf[$identifier.'.'][$key].'.');
		}
		
		return $value;
	}
	
	
	/**
	 *  Gets an configuration array for the icon of a soacial media link.
	 *  
	 *  @param $socialmedialink Social media link item.
	 *  
	 *  @return array Array containing the keys 'url', 'width' and 'height' or false, if no icon exists.
	 */
	function getItemIcon($socialmedialink) {
		$imgConf = array();

		if(intval($socialmedialink['icon']) > 0) {
			// dam file
			$files = tx_dam_db::getReferencedFiles('tx_form4socialmedialinks_entry', $socialmedialink['uid'], 'tx_form4socialmedialinks_icon');
			foreach($files['files'] as $key => $value) {
				$imgConf['file'] = $value;
			}
		} else if(strlen(trim($socialmedialink['icon'])) > 0) {
			// normal upload file
			$imgConf['file'] = "uploads/tx_form4socialmedialinks/" . $socialmedialink['icon'];
		}
		
		if($this->getItemTSConfigValue($socialmedialink['identifier'], 'icon_maxW') > 0) {
			$imgConf['file.']['maxW']  = $this->getItemTSConfigValue($socialmedialink['identifier'], 'icon_maxW');
		}
		if($this->getItemTSConfigValue($socialmedialink['identifier'], 'icon_maxH') > 0) {
			$imgConf['file.']['maxH']  = $this->getItemTSConfigValue($socialmedialink['identifier'], 'icon_maxH');
		}
		
		$this->cObj->IMAGE($imgConf);

		if(is_array($GLOBALS["TSFE"]->lastImageInfo) && count($GLOBALS["TSFE"]->lastImageInfo) > 3) {
			$imagewidth  = $GLOBALS["TSFE"]->lastImageInfo[0];
			$imageheight = $GLOBALS["TSFE"]->lastImageInfo[1];
			$imageurl    = $GLOBALS["TSFE"]->lastImageInfo[3];
			
			return array('url' => $imageurl, 'width' => $imagewidth, 'height' => $imageheight);
		}
		
		return FALSE;
	}
	
	/**
	 *  Processes the placeholder TS configuration. Returns an array with the placeholder key and 
	 *  the value, the placholder key will be replaced by.
	 */
	private function preparePlaceholder() {
		$placeholders = array();
		
		$placeholderConf = $this->conf['placeholder.'];
		foreach($placeholderConf as $key => $pConf) {
			if(!preg_match('/\.$/', $key)) {
				// interpret TS
				$value = $this->cObj->cObjGetSingle($placeholderConf[$key],$placeholderConf[$key.'.']);
				$placeholders[$key] = $value;
			}
		}
		
		return $placeholders;
	}
	
	function getSocialMediaLink($uid=0) {
		$socialmedialinks = $this->getSocialMediaLinks($uid);
 		if(!empty($socialmedialinks)) {
 			return $socialmedialinks[0];
 		}
 		return false;
	}
	
	
	function getSocialMediaLinks($uid=0) {
		$q = array();
		$q['select'] 	= '*';
		$q['from'] 		= 'tx_form4socialmedialinks_entry';
		$q['where'] 	= "deleted='0' AND hidden='0'";
		if(intval($uid) > 0) {
			$q['where'] .= " AND uid='".intval($uid)."'";
		}
		
		$q['groupby'] 	= "";
		$q['orderby'] 	= "sorting";
		$q['limit'] 	= "";
			
		$socialmedialinks = $GLOBALS["TYPO3_DB"]->exec_SELECTgetRows($q['select'],$q['from'],$q['where'],$q['groupby'],$q['orderby'],$q['limit']);
		
		/*
		if(!empty($socialmedialinks) && intval($this->sys_language_uid) > 0) {
			$result = array();
			foreach($socialmedialinks as $link) {
				$ol = $GLOBALS['TSFE']->sys_page->getPageOverlay('tx_form4socialmedialinks_entry', $link, $this->sys_language_uid);
				if($ol) {
					$result[] = $ol;
				}
			}
			return $result;
		}
		*/
		
		return $socialmedialinks;	
	}
	
	function getSocialMediaLinkByIdentifier($identifier) {
		$identifier = trim($identifier);
		
		$q = array();
		$q['select'] 	= '*';
		$q['from'] 		= 'tx_form4socialmedialinks_entry';
		$q['where'] 	= "deleted='0' AND hidden='0'";
		if(strlen($identifier) > 0) {
			$q['where'] .= " AND identifier='".$identifier."'";
		}
		
		$q['groupby'] 	= "";
		$q['orderby'] 	= "sorting";
		$q['limit'] 	= "";
			
		$socialmedialinks = $GLOBALS["TYPO3_DB"]->exec_SELECTgetRows($q['select'],$q['from'],$q['where'],$q['groupby'],$q['orderby'],$q['limit']);
		
		if(!empty($socialmedialinks)) {
			/*
			if(intval($this->sys_language_uid) > 0) {
				$ol = $GLOBALS['TSFE']->sys_page->getPageOverlay('tx_form4socialmedialinks_entry', $socialmedialinks[0], $this->sys_language_uid, 'hideNonTranslated');
				return $ol;
			}
			*/
 			return $socialmedialinks[0];
 		}
		return FALSE;	
	}

}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/form4_socialmedialinks/pi1/class.tx_form4socialmedialinks_pi1.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/form4_socialmedialinks/pi1/class.tx_form4socialmedialinks_pi1.php']);
}

?>